<?php
namespace Neklo\Scheduler\Block\Adminhtml\Schedule\Edit;

use Neklo\Scheduler\Controller\Adminhtml\Schedule\Edit as EditCtrl;
use Neklo\Scheduler\Api\Data\SchedulerInterface;

class Form extends \Magento\Backend\Block\Widget\Form\Generic
{
    /**
     *
     * @var \Neklo\Scheduler\Helper\Job
     */
    protected $jobHelper;
    protected $statusHelper;

    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Neklo\Scheduler\Helper\Job $jobHelper,
        \Neklo\Scheduler\Helper\Status $statusHelper,
        array $data = []
    ) {
        parent::__construct($context, $registry, $formFactory, $data);
        $this->jobHelper = $jobHelper;
        $this->statusHelper = $statusHelper;
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('schedule_form');
        $this->setTitle(__('Scheduled Job Information'));
        $this->setAction('*/schedule/save');
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create(
            ['data' => [
                'id' => 'edit_form',
                'action' => $this->getData('action'),
                'method' => 'post']
            ]
        );

        $form->setHtmlIdPrefix('block_');

        $fieldset = $form->addFieldset(
            'base_fieldset',
            ['legend' => __('General Information'), 'class' => 'fieldset-wide']
        );

        $fieldset->addField(
            SchedulerInterface::SCHEDULE_ID,
            'hidden',
            ['name' => SchedulerInterface::SCHEDULE_ID]);

        $fieldset->addField(
            SchedulerInterface::SCHEDULE_CODE,
            'select',
            [
                'name' => SchedulerInterface::SCHEDULE_CODE,
                'label' => __('Name'),
                'title' => __('Name'),
                'values' => $this->jobHelper->getJobNameOptions()]
        );

        $fieldset->addField(
            SchedulerInterface::SCHEDULE_SCHEDULED,
            'date',
            [
                'name' => SchedulerInterface::SCHEDULE_SCHEDULED,
                'label' => __('Time Scheduled'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled' => false,
                'class' => 'validate-date validate-date-range date-range-custom_theme-from'
            ]
        );
        $fieldset->addField(
            SchedulerInterface::SCHEDULE_CREATED,
            'date',
            [
                'name' => SchedulerInterface::SCHEDULE_CREATED,
                'label' => __('Time Created'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled' => false,
                'class' => 'validate-date validate-date-range date-range-custom_theme-from'
            ]
        );
        $fieldset->addField(
            SchedulerInterface::SCHEDULE_EXECUTED,
            'date',
            [
                'name' => SchedulerInterface::SCHEDULE_EXECUTED,
                'label' => __('Time Executed'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled' => false,
                'class' => 'validate-date validate-date-range date-range-custom_theme-from'
            ]
        );
        $fieldset->addField(
            SchedulerInterface::SCHEDULE_FINISH,
            'date',
            [
                'name' => SchedulerInterface::SCHEDULE_FINISH,
                'label' => __('Time Finished'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled' => false,
                'class' => 'validate-date validate-date-range date-range-custom_theme-from'
            ]
        );
        $fieldset->addField(
            SchedulerInterface::SCHEDULE_STATUS,
            'select',
            [
                'name' => SchedulerInterface::SCHEDULE_STATUS,
                'label' => __('Status'),
                'disabled' => false,
                'values' => $this->statusHelper->getOptions()
            ]
        );
        $model = $this->_coreRegistry->registry(EditCtrl::MODEL_REGISTRY);
        $form->setValues($model->getData());
        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}
